package com.fs.hospital.service;

import java.util.List;
import com.fs.hospital.domain.HospitalMemberIntegralLogs;
import com.fs.hospital.vo.HospitalMemberIntegralLogsListHVO;

/**
 * 积分记录Service接口
 *
 * @author fs
 * @date 2024-03-04
 */
public interface IHospitalMemberIntegralLogsService
{
    /**
     * 查询积分记录
     *
     * @param id 积分记录主键
     * @return 积分记录
     */
    public HospitalMemberIntegralLogs selectHospitalMemberIntegralLogsById(Long id);

    /**
     * 查询积分记录列表
     *
     * @param hospitalMemberIntegralLogs 积分记录
     * @return 积分记录集合
     */
    public List<HospitalMemberIntegralLogs> selectHospitalMemberIntegralLogsList(HospitalMemberIntegralLogs hospitalMemberIntegralLogs);

    /**
     * 新增积分记录
     *
     * @param hospitalMemberIntegralLogs 积分记录
     * @return 结果
     */
    public int insertHospitalMemberIntegralLogs(HospitalMemberIntegralLogs hospitalMemberIntegralLogs);

    /**
     * 修改积分记录
     *
     * @param hospitalMemberIntegralLogs 积分记录
     * @return 结果
     */
    public int updateHospitalMemberIntegralLogs(HospitalMemberIntegralLogs hospitalMemberIntegralLogs);

    /**
     * 批量删除积分记录
     *
     * @param ids 需要删除的积分记录主键集合
     * @return 结果
     */
    public int deleteHospitalMemberIntegralLogsByIds(Long[] ids);

    /**
     * 删除积分记录信息
     *
     * @param id 积分记录主键
     * @return 结果
     */
    public int deleteHospitalMemberIntegralLogsById(Long id);

    List<HospitalMemberIntegralLogsListHVO> selectHospitalMemberIntegralLogsListPVO(HospitalMemberIntegralLogs hospitalMemberIntegralLogs);

    int addHospitalMemberIntegral(HospitalMemberIntegralLogs hospitalMemberIntegralLogs);
    int subHospitalMemberIntegral(HospitalMemberIntegralLogs hospitalMemberIntegralLogs);
}
